pub struct ViewTransitionsPlugin;Expand description
Plugin that injects the View Transitions API client + style hooks.
Opt-in via SsgConfig::transitions; when false the plugin is
never registered (see core::pipeline::register_default_plugins).
Examples
use ssg::plugin::Plugin;
use ssg::view_transitions::ViewTransitionsPlugin;
assert_eq!(ViewTransitionsPlugin::new().name(), "view-transitions");Implementations
Sourceimpl ViewTransitionsPlugin
impl ViewTransitionsPlugin
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates a new instance.
Examples
use ssg::view_transitions::ViewTransitionsPlugin;
let _plugin = ViewTransitionsPlugin::new();Sourcepub const fn enabled(cfg: &SsgConfig) -> bool
pub const fn enabled(cfg: &SsgConfig) -> bool
Returns whether cfg opts in to transitions.
Examples
use ssg::cmd::SsgConfig;
use ssg::view_transitions::ViewTransitionsPlugin;
let cfg = SsgConfig::builder()
.site_name("t".into())
.base_url("http://example.com".into())
.build()
.unwrap();
assert!(!ViewTransitionsPlugin::enabled(&cfg));Trait Implementations
Sourceimpl Clone for ViewTransitionsPlugin
impl Clone for ViewTransitionsPlugin
Sourcefn clone(&self) -> ViewTransitionsPlugin
fn clone(&self) -> ViewTransitionsPlugin
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ViewTransitionsPlugin
Sourceimpl Debug for ViewTransitionsPlugin
impl Debug for ViewTransitionsPlugin
Sourceimpl Default for ViewTransitionsPlugin
impl Default for ViewTransitionsPlugin
Sourcefn default() -> ViewTransitionsPlugin
fn default() -> ViewTransitionsPlugin
Returns the “default value” for a type. Read more
Sourceimpl Plugin for ViewTransitionsPlugin
impl Plugin for ViewTransitionsPlugin
Sourcefn has_transform(&self) -> bool
fn has_transform(&self) -> bool
Returns
true if this plugin implements transform_html.
Override to true to opt in to the fused transform pass.Sourcefn transform_html(
&self,
html: &str,
_path: &Path,
_ctx: &PluginContext,
) -> Result<String, SsgError>
fn transform_html( &self, html: &str, _path: &Path, _ctx: &PluginContext, ) -> Result<String, SsgError>
Per-file HTML transform hook — called once per HTML file during
the fused transform pass. Read more
Sourcefn after_compile(&self, ctx: &PluginContext) -> Result<(), SsgError>
fn after_compile(&self, ctx: &PluginContext) -> Result<(), SsgError>
Called after site compilation completes. Read more
Sourcefn before_compile(&self, _ctx: &PluginContext) -> Result<(), SsgError>
fn before_compile(&self, _ctx: &PluginContext) -> Result<(), SsgError>
Called before site compilation begins. Read more
Sourcefn needs_all_files(&self) -> bool
fn needs_all_files(&self) -> bool
Returns
true if this plugin must always observe the full
cache.html_files() list — even during --incremental
rebuilds that only invalidated a handful of pages. Read moreAuto Trait Implementations
impl Freeze for ViewTransitionsPlugin
impl RefUnwindSafe for ViewTransitionsPlugin
impl Send for ViewTransitionsPlugin
impl Sync for ViewTransitionsPlugin
impl Unpin for ViewTransitionsPlugin
impl UnsafeUnpin for ViewTransitionsPlugin
impl UnwindSafe for ViewTransitionsPlugin